import React from 'react';
/**
 * Props for the JsxParser component
 */
export type TProps = {
    /** Whether to allow rendering of unrecognized HTML elements. Defaults to true. */
    allowUnknownElements?: boolean;
    /**
     * Whether to auto-close void elements like <img>, <br>, <hr> etc. in HTML style.
     * Defaults to false.
     */
    autoCloseVoidElements?: boolean;
    /** Object containing values that can be referenced in the JSX string */
    bindings?: {
        [key: string]: unknown;
    };
    /**
     * Array of attribute names or RegExp patterns to blacklist.
     * By default removes 'on*' attributes
     */
    blacklistedAttrs?: Array<string | RegExp>;
    /**
     * Array of HTML tag names to blacklist.
     * By default removes 'script' tags
     */
    blacklistedTags?: string[];
    /** CSS class name(s) to add to the wrapper div */
    className?: string;
    /** Map of component names to their React component definitions */
    components?: Record<string, React.ComponentType | React.ExoticComponent | (() => React.ReactNode)>;
    /** If true, only renders custom components defined in the components prop */
    componentsOnly?: boolean;
    /** If true, disables usage of React.Fragment. May affect whitespace handling */
    disableFragments?: boolean;
    /** If true, disables automatic generation of key props */
    disableKeyGeneration?: boolean;
    /** The JSX string to parse and render */
    jsx?: string;
    /** Callback function when parsing/rendering errors occur */
    onError?: (error: Error) => void;
    /** If true, shows parsing/rendering warnings in console */
    showWarnings?: boolean;
    /** Custom error renderer function */
    renderError?: (props: {
        error: string;
    }) => React.ReactNode | null;
    /** Whether to wrap output in a div. If false, renders children directly */
    renderInWrapper?: boolean;
    /** Custom renderer for unrecognized elements */
    renderUnrecognized?: (tagName: string) => React.ReactNode | null;
};
export default class JsxParser extends React.Component<TProps> {
    #private;
    static displayName: string;
    static defaultProps: TProps;
    /** Stores the parsed React elements */
    private ParsedChildren;
    /**
     * Renders the parsed JSX content
     * @returns The rendered React elements wrapped in a div (if renderInWrapper is true)
     */
    render(): string | number | boolean | Iterable<React.ReactNode> | React.JSX.Element | null | undefined;
}
